@@ -429,7 +429,7 @@ class SpawnCommandTest(unittest.TestCase):
         sshx.handle_connect(NAME1)
         command = sshwrap._SSH_COMMAND_PASSWORD.format(
             user=USER1, host=HOST1, port=PORT1, identity=NOIDENTITY,
-            extras='', forwards='', jump='', cmd='',
+            extras='-o ServerAliveInterval=15 -o ServerAliveCountMax=210240000', forwards='', jump='', cmd='',
         )
         _assert_called_with(m, command)
 
@@ -437,14 +437,14 @@ class SpawnCommandTest(unittest.TestCase):
         sshx.handle_connect(NAME2)
         command = sshwrap._SSH_COMMAND_IDENTITY.format(
             user=USER2, host=HOST2, port=PORT2, identity=IDENTITY2,
-            extras='', forwards='', jump='', cmd='',
+            extras='-o ServerAliveInterval=15 -o ServerAliveCountMax=210240000', forwards='', jump='', cmd='',
         )
         _assert_called_with(m, command)
 
     # mock the __del__ to avoid deleting config file
     # mock the uuid to set the config file
     # mock spawn to get the executed command
-    @mock.patch('sshx.sshwrap.AccountChain.__del__')
+    @mock.patch('sshx.utils.delete_file')
     @mock.patch('sshx.sshwrap.uuid.uuid4', return_value=_SSH_CONFIG_FILE)
     @mock.patch('pexpect.spawn', autospec=True)
     def test_connect_via(self, m, m_uuid, m_del):
@@ -474,7 +474,8 @@ class SpawnCommandTest(unittest.TestCase):
         sshx.handle_forward(NAME1, maps=(FORWARD1,))
         command = sshwrap._SSH_COMMAND_PASSWORD.format(
             user=USER1, host=HOST1, port=PORT1, identity=NOIDENTITY,
-            extras='-NT', forwards=f'-L {FORWARD1}', jump='', cmd='',
+            extras='-NT -o ServerAliveInterval=15 -o ServerAliveCountMax=210240000',
+            forwards=f'-L {FORWARD1}', jump='', cmd='',
         )
         _assert_called_with(m, command)
         m_daemon.assert_not_called()
@@ -483,12 +484,13 @@ class SpawnCommandTest(unittest.TestCase):
         sshx.handle_forward(NAME1, maps=(FORWARD1,), background=True)
         command = sshwrap._SSH_COMMAND_PASSWORD.format(
             user=USER1, host=HOST1, port=PORT1, identity=NOIDENTITY,
-            extras='-NT', forwards=f'-L {FORWARD1}', jump='', cmd='',
+            extras='-NT -o ServerAliveInterval=15 -o ServerAliveCountMax=210240000',
+            forwards=f'-L {FORWARD1}', jump='', cmd='',
         )
         _assert_called_with(m, command)
         m_daemon.assert_called_once()
 
-    @mock.patch('sshx.sshwrap.AccountChain.__del__')
+    @mock.patch('sshx.utils.delete_file')
     @mock.patch('sshx.sshwrap.uuid.uuid4', return_value=_SSH_CONFIG_FILE)
     @mock.patch('pexpect.spawn', autospec=True)
     def test_forward_via(self, m, m_uuid, m_del):
@@ -519,23 +521,23 @@ class SpawnCommandTest(unittest.TestCase):
         )
         _assert_called_with(m, command)
 
-    @mock.patch('sshx.sshwrap.AccountChain.__del__')
+    @mock.patch('sshx.utils.delete_file')
     @mock.patch('sshx.sshwrap.uuid.uuid4', return_value=_SSH_CONFIG_FILE)
     @mock.patch('pexpect.spawn', autospec=True)
     def test_scp_via(self, m, m_uuid, m_del):
         '''sshx scp -v <NAME4> <DIR1> <NAME1>:<DIR2>'''
         sshx.handle_scp(DIR1, f'{NAME1}:{DIR2}', via=NAME4)
         command = sshwrap._SCP_COMMAND_CONFIG.format(
-            name=NAME1, extras=f'-F {SSH_CONFIG_FILE}', jump='',
-            src=DIR1, dst=f'{NAME1}:{DIR2}')
+            name=NAME1, extras=f'-F {SSH_CONFIG_FILE}',
+            jump='', src=DIR1, dst=f'{NAME1}:{DIR2}')
         _assert_called_with(m, command)
         _assert_file_contains(self, SSH_CONFIG_FILE, f'Host {NAME4}')
 
         '''sshx scp -v <NAME3>,<NAME4> <DIR1> <NAME1>:<DIR2>'''
         sshx.handle_scp(DIR1, f'{NAME1}:{DIR2}', via=f'{NAME3},{NAME4}')
         command = sshwrap._SCP_COMMAND_CONFIG.format(
-            name=NAME1, extras=f'-F {SSH_CONFIG_FILE}', jump='',
-            src=DIR1, dst=f'{NAME1}:{DIR2}')
+            name=NAME1, extras=f'-F {SSH_CONFIG_FILE}',
+            jump='', src=DIR1, dst=f'{NAME1}:{DIR2}')
         _assert_called_with(m, command)
         _assert_file_contains(self, SSH_CONFIG_FILE,
                               [f'Host {NAME3}', f'Host {NAME4}',
@@ -560,7 +562,8 @@ class SpawnCommandTest(unittest.TestCase):
 
         command1 = sshwrap._SSH_COMMAND_PASSWORD.format(
             user=USER4, host=HOST4, port=PORT4, identity=IDENTITY4,
-            extras='-NT', forwards=f'-L {sshwrap.LOCALHOST}:{LOCALPORT}:{HOST1}:{PORT1}', jump='', cmd='',
+            extras='-NT',
+            forwards=f'-L {sshwrap.LOCALHOST}:{LOCALPORT}:{HOST1}:{PORT1}', jump='', cmd='',
         )
 
         command2 = sshwrap._SCP_COMMAND_PASSWORD.format(
@@ -572,7 +575,7 @@ class SpawnCommandTest(unittest.TestCase):
 
     # mock interactive to pretend the forwarding was successfully established,
     # otherwise interactive would failed because there's no real ssh connection.
-    @mock.patch('sshx.sshwrap.AccountChain.__del__')
+    @mock.patch('sshx.utils.delete_file')
     @mock.patch('sshx.sshwrap.uuid.uuid4', return_value=_SSH_CONFIG_FILE)
     @mock.patch('sshx.sshwrap.SSHPexpect.interactive', return_value=STATUS_SUCCESS)
     @mock.patch('sshx.sshwrap.find_available_port', return_value=LOCALPORT)
@@ -583,8 +586,8 @@ class SpawnCommandTest(unittest.TestCase):
                         via=f'{NAME4},{NAME5}', with_forward=True)
 
         command1 = sshwrap._SSH_COMMAND_CONFIG.format(
-            name=NAME5, extras=f'-NT -F {SSH_CONFIG_FILE}', cmd='', jump='',
-            forwards=f'-L {sshwrap.LOCALHOST}:{LOCALPORT}:{HOST1}:{PORT1}')
+            name=NAME5, extras=f'-NT -F {SSH_CONFIG_FILE}',
+            cmd='', jump='', forwards=f'-L {sshwrap.LOCALHOST}:{LOCALPORT}:{HOST1}:{PORT1}')
         _assert_file_contains(self, SSH_CONFIG_FILE, f'Host {NAME4}')
 
         command2 = sshwrap._SCP_COMMAND_PASSWORD.format(
@@ -601,7 +604,8 @@ class SpawnCommandTest(unittest.TestCase):
         sshx.handle_socks(NAME1)
         command = sshwrap._SSH_COMMAND_PASSWORD.format(
             user=USER1, host=HOST1, port=PORT1, identity=NOIDENTITY,
-            extras='-D 1080 -NT', forwards='', jump='', cmd='',
+            extras='-D 1080 -NT -o ServerAliveInterval=15 -o ServerAliveCountMax=210240000',
+            forwards='', jump='', cmd='',
         )
         _assert_called_with(m, command)
 
@@ -611,11 +615,11 @@ class SpawnCommandTest(unittest.TestCase):
         sshx.handle_exec(NAME1, cmd=COMMAND1.split(), tty=True)
         command = sshwrap._SSH_COMMAND_PASSWORD.format(
             user=USER1, host=HOST1, port=PORT1, identity=NOIDENTITY,
-            extras='-t', forwards='', jump='', cmd=COMMAND1,
+            extras='-t -o ServerAliveInterval=15 -o ServerAliveCountMax=210240000', forwards='', jump='', cmd=COMMAND1,
         )
         _assert_called_with(m, command)
 
-    @mock.patch('sshx.sshwrap.AccountChain.__del__')
+    @mock.patch('sshx.utils.delete_file')
     @mock.patch('sshx.sshwrap.uuid.uuid4', return_value=_SSH_CONFIG_FILE)
     @mock.patch('pexpect.spawn', autospec=True)
     def test_exec_via(self, m, m_uuid, m_del):
@@ -637,7 +641,7 @@ class SpawnCommandTest(unittest.TestCase):
             identity=PUBKEY, extras='')
         _assert_called_with(m, command)
 
-    @mock.patch('sshx.sshwrap.AccountChain.__del__')
+    @mock.patch('sshx.utils.delete_file')
     @mock.patch('sshx.sshwrap.uuid.uuid4', return_value=_SSH_CONFIG_FILE)
     @mock.patch('sshx.sshwrap.SSHPexpect.interactive', return_value=STATUS_SUCCESS)
     @mock.patch('sshx.sshwrap.find_available_port', return_value=LOCALPORT)
@@ -647,8 +651,8 @@ class SpawnCommandTest(unittest.TestCase):
         sshx.handle_copyid(NAME1, PUBKEY, via=f'{NAME4},{NAME5}')
 
         command1 = sshwrap._SSH_COMMAND_CONFIG.format(
-            name=NAME5, extras=f'-NT -F {SSH_CONFIG_FILE}', cmd='', jump='',
-            forwards=f'-L {sshwrap.LOCALHOST}:{LOCALPORT}:{HOST1}:{PORT1}')
+            name=NAME5, extras=f'-NT -F {SSH_CONFIG_FILE}',
+            cmd='', jump='', forwards=f'-L {sshwrap.LOCALHOST}:{LOCALPORT}:{HOST1}:{PORT1}')
         _assert_file_contains(self, SSH_CONFIG_FILE, f'Host {NAME4}')
 
         command2 = sshwrap._SSH_COPYID.format(
